@@ -1,15 +1,17 @@
 test_that("precipitation indicator works", {
+  skip_on_cran()
   x <- read_sf(
     system.file("extdata", "gfw_sample.gpkg",
       package = "mapme.biodiversity"
     )
   )
-  x <- suppressWarnings(st_cast(x, to = "POLYGON"))[1, ]
+  .clear_resources()
+  outdir <- file.path(tempdir(), "mapme.data")
+  .copy_resource_dir(outdir)
+  mapme_options(outdir = outdir, verbose = FALSE)
+  get_resources(x, get_chirps(years = 2010))
+  chirps <- prep_resources(x)[["chirps"]]
 
-  chirps <- list.files(system.file("res", "chirps",
-    package = "mapme.biodiversity"
-  ), pattern = "tif$", full.names = TRUE)
-  chirps <- rast(chirps)
   expect_message(cpc <- calc_precipitation_chirps(1980:1982))
   expect_error(calc_precipitation_chirps(years = 1970:1971))
   expect_error(calc_precipitation_chirps(years = 1981:1982, engine = "not-av"))
