@@ -4,9 +4,11 @@ test_that("mapme_options works", {
   expect_equal(names(opts), names)
 
   expect_error(mapme_options(outdir = 1))
+  expect_error(mapme_options(outdir = "/does-not-exist"), "not writeable via GDAL")
   expect_error(mapme_options(verbose = 1))
   expect_error(mapme_options(chunk_size = "a"))
   expect_error(mapme_options(retries = "a"))
+  expect_silent(mapme_options(outdir = NULL))
 })
 
 test_that("test register_resource works", {
